@@ -238,16 +238,23 @@ class EnhancedAdminMixin(admin.ModelAdmin, EnhancedBaseAdminMixin):
     def get_extra_changelist_links(self, request):
         return self.extra_changelist_links
 
+    def get_fieldset_section_exclusions(self, request, obj):
+        return []
+
     def get_fieldset_field_exclusions(self, request, obj):
         return []
 
     def get_fieldsets(self, request, obj=None):
         original_fieldsets = super().get_fieldsets(request, obj)
-        exclusions = self.get_fieldset_field_exclusions(request, obj)
-        if not exclusions:
+        field_exclusions = self.get_fieldset_field_exclusions(request, obj)
+        section_exclusions = self.get_fieldset_section_exclusions(request, obj)
+        if not field_exclusions and not section_exclusions:
             return original_fieldsets
         fieldsets = deepcopy(original_fieldsets)
-        remove_from_fieldsets(fieldsets, exclusions)
+        if section_exclusions:
+            fieldsets = [(title, attributes) for title, attributes in fieldsets if title not in section_exclusions]
+        if field_exclusions:
+            remove_from_fieldsets(fieldsets, field_exclusions)
         return fieldsets
 
 
